@@ -33,15 +33,20 @@
 #include <QDBusConnection>
 #include <QDBusError>
 #include <QTimer>
+#include "k9batch.h"
 
 static const char description[] =
-    I18N_NOOP("A DVD Backup software for KDE");
+        I18N_NOOP("A DVD Backup software for KDE");
 
 static const char version[] = VERSION ;
 
 int main(int argc, char **argv) {
+    k9batch batch;
+    if (batch.exec(argc,argv)) 
+      return 1;
+    
     KAboutData about("k9copy", 0, ki18n("k9copy"), version, ki18n(description),
-                     KAboutData::License_GPL, ki18n("(C) 2009 Jean-Michel PETIT"), KLocalizedString(), 0, "k9copy@free.fr");
+                     KAboutData::License_GPL, ki18n("(C) 2004-2010 Jean-Michel PETIT"), KLocalizedString(), 0, "k9copy@free.fr");
     about.addAuthor( ki18n("Jean-Michel PETIT"), KLocalizedString(), "k9copy@free.fr" );
     about.setTranslator(ki18n("_: NAME OF TRANSLATORS\\nYour names")
                         ,ki18n("_: EMAIL OF TRANSLATORS\\nYour emails"));
@@ -53,10 +58,11 @@ int main(int argc, char **argv) {
     options.add("dvdtitle <number>", ki18n("title to play"));
     options.add("assistant", ki18n("the k9copy backup assistant"));
 
+
     KCmdLineArgs::addCmdLineOptions( options );
 
-//    KCmdLineOptions options;
-//    options.add("+[URL]", ki18n( "Document to open" ));
+    //    KCmdLineOptions options;
+    //    options.add("+[URL]", ki18n( "Document to open" ));
     KCmdLineArgs::addCmdLineOptions(options);
     KApplication app;
 
@@ -70,31 +76,31 @@ int main(int argc, char **argv) {
         QString OutputOptionArg( args->getOption("output"));
         k9Config::checkCodecs();
         if (!args->isSet("assistant")) {
-		k9Copy  *widget = new k9Copy;
-		if (InputOptionArg !="") {
+            k9Copy  *widget = new k9Copy;
+            if (InputOptionArg !="") {
 		widget->setInput( InputOptionArg);
 		widget->fileOpen();
-		}
-		if (OutputOptionArg !="")
+            }
+            if (OutputOptionArg !="")
 		widget->setOutput( OutputOptionArg);
-	
-		if ((InputOptionArg !="") && (OutputOptionArg!=""))
+
+            if ((InputOptionArg !="") && (OutputOptionArg!=""))
 		widget->clone( InputOptionArg,OutputOptionArg);
-		widget->show();
-	} else {
-		k9Assistant *ast=k9Assistant::createAssistant();
-		if (InputOptionArg !="") 
-		  ast->setPath(InputOptionArg);
-		k9Dialogs::setMainWidget(ast);
-   	        QTimer::singleShot (10, ast, SLOT (run ()));
+            widget->show();
+        } else {
+            k9Assistant *ast=k9Assistant::createAssistant();
+            if (InputOptionArg !="")
+                ast->setPath(InputOptionArg);
+            k9Dialogs::setMainWidget(ast);
+            QTimer::singleShot (10, ast, SLOT (run ()));
 
 	}	
 
-    int res=app.exec();
-    k9Config config;
-    if (config.getPrefDelTmpFiles())
-	k9Tools::clearOutput();
-    
-    return res;
+        int res=app.exec();
+        k9Config config;
+        if (config.getPrefDelTmpFiles())
+            k9Tools::clearOutput();
+
+        return res;
     }
 }
