@@ -23,8 +23,6 @@
 #include "k9ifo2.h"
 #include "k9vamps.h"
 #include "k9dvdtitleset.h"
-#include <kmessagebox.h>
-#include <kapplication.h>
 #include <qapplication.h>
 #include <qfileinfo.h>
 
@@ -33,9 +31,14 @@
 #include <stdarg.h>
 #include <errno.h>
 #include <string.h>
-#include <klocale.h>
 #include <qdir.h>
+#ifndef BACKLITE
 #include <kstandarddirs.h>
+#include <kmessagebox.h>
+#include <kapplication.h>
+#include <klocale.h>
+#endif
+
 #include "k9backupdlg.h"
 #include "dvdread.h"
 #include "k9script.h"
@@ -83,6 +86,13 @@ uint32_t k9TitleSet::getSize() {
 }
 
 
+bool k9DVDBackup::isAborted() {
+    if (!k9Tools::getBatchCopy())
+        return backupDlg->getAbort();
+    else
+        return false;
+}
+
 k9DVDBackup::k9DVDBackup(QObject* _dvd )
         : k9DVDBackupInterface(NULL) {
     DVD = (k9DVD*)_dvd;
@@ -92,7 +102,7 @@ k9DVDBackup::k9DVDBackup(QObject* _dvd )
     currTS=NULL;
     errMsg="";
     error=false;
-    backupDlg = new k9BackupDlg(k9Dialogs::getMainWidget());
+    backupDlg = k9Tools::getBatchCopy() ? NULL : new k9BackupDlg(k9Dialogs::getMainWidget());
     //  cells.setAutoDelete(true);
     vamps=new k9vamps(this);
     m_withMenu=false;
@@ -107,7 +117,8 @@ k9DVDBackup::~k9DVDBackup() {
         outputFile->close();
         delete outputFile;
     }
-    delete backupDlg;
+    if (backupDlg)
+        delete backupDlg;
     delete vamps;
 }
 
@@ -145,8 +156,8 @@ void k9DVDBackup::prepareVTS(int _VTS) {
             outputFile=NULL;
         }
     }
-    if (backupDlg->getAbort()) {
-        seterror(tr2i18n("DVD backup cancelled"));
+    if (isAborted()) {
+        seterror(i18n("DVD backup cancelled"));
         return;
     }
     //creation of output file
@@ -159,8 +170,8 @@ void k9DVDBackup::prepareVTS(int _VTS) {
             updateVob(&currTS->cells);
         }
 
-        if (backupDlg->getAbort()) {
-            seterror(tr2i18n("DVD backup cancelled"));
+        if (isAborted()) {
+            seterror(i18n("DVD backup cancelled"));
             return;
         }
 
@@ -173,7 +184,7 @@ void k9DVDBackup::prepareVTS(int _VTS) {
             kifo=m_dvdread->getIfo(0);
             hifo = kifo->getIFO();
             if (!hifo) {
-                seterror( tr2i18n("unable to open VIDEO_TS.IFO"));
+                seterror( i18n("unable to open VIDEO_TS.IFO"));
                 return;
             }
             startSector= hifo->vmgi_mat->vmg_last_sector+1  ;
@@ -194,8 +205,8 @@ void k9DVDBackup::prepareVTS(int _VTS) {
         filename.sprintf("/VTS_%02d_1.VOB",_VTS);
         filename=output+filename;
         outputFile=new QFile(filename);
-        if (! outputFile->open(QIODevice::WriteOnly)) {
-            seterror(tr2i18n("Unable to open file ") + filename);
+        if (! outputFile->open(QIODevice::ReadWrite | QIODevice::Unbuffered)) {
+            seterror(i18n("Unable to open file ") + filename);
             return;
         }
 
@@ -261,7 +272,7 @@ void k9DVDBackup::copyCell(int _VTS,k9Cell * _cell,bool _empty) {
         playCell(_VTS,_cell,_empty);
     } else
         copyEmptyPgc(_VTS,_cell);
-    qApp->processEvents();
+    k9Tools::processEvents();
 }
 
 void k9DVDBackup::copyEmptyPgc(int _vts,k9Cell *_cell) {
@@ -274,22 +285,23 @@ void k9DVDBackup::copyEmptyPgc(int _vts,k9Cell *_cell) {
     k9DVDFile *dvdfile;
     if ((dvdfile = m_dvdread->openTitle( _vts))== 0) {
         QString stmp;
-        stmp=i18n("Unable to open titleset %1",_vts);
+        stmp=i18n("Unable to open titleset %1").arg(_vts);
         seterror(stmp);
         return ;
     }
-    backupDlg->setTotalSteps(vts_handle->vtsi_mat->vts_last_sector-vts_handle->vtsi_mat->vtstt_vobs  -1);
+    setTotalSteps(vts_handle->vtsi_mat->vts_last_sector-vts_handle->vtsi_mat->vtstt_vobs  -1);
     QString c;
-    c=i18n("Extracting titleset %1",_vts);
-    backupDlg->setProgressLabel(c);
-    backupDlg->show();
+    c=i18n("Extracting titleset %1").arg(_vts);
+    setProgressLabel(c);
+    if (!k9Tools::getBatchCopy())
+        backupDlg->show();
 
 
     uint32_t sector;
     int32_t len=0;
     uchar buffer[DVD_VIDEO_LB_LEN];
     sector = _cell->startSector;
-    backupDlg->setProgress(sector);
+    setProgress(sector);
     dsi_t	 dsi_pack;
     uint32_t	 nsectors;
 
@@ -320,7 +332,7 @@ void k9DVDBackup::copyEmptyPgc(int _vts,k9Cell *_cell) {
     currCell->cellList->setPosition(currCell->cellList->getPosition()+1+len);
     currTS->lastSector+=len+1;
     dvdfile->close();
-    backupDlg->setProgressTotal(len+1);
+    setProgressTotal(len+1);
     if (!m_forcedFactor) {
         m_cellCopyList->addInbytes( DVD_VIDEO_LB_LEN *2);
         m_cellCopyList->addOutbytes( DVD_VIDEO_LB_LEN *2);
@@ -335,7 +347,8 @@ void k9DVDBackup::copyEmptyPgc(int _vts,k9Cell *_cell) {
 void k9DVDBackup::getOutput(uchar * buffer, uint32_t buflen) {
     if (error)
         return;
-    backupDlg->playMovie(buffer,buflen);
+    if (!k9Tools::getBatchCopy())
+        backupDlg->playMovie(buffer,buflen);
 
     if (!m_forcedFactor)
         m_cellCopyList->addOutbytes( buflen);
@@ -375,17 +388,18 @@ void k9DVDBackup::getOutput(uchar * buffer, uint32_t buflen) {
                     sName.sprintf("/VTS_%02d_%d.VOB",(int)currVTS,(int)currVOB);
                 sName=output+sName;
                 outputFile=new QFile(sName);
-                if ( !outputFile->open(QIODevice::WriteOnly)) {
-                    seterror(tr2i18n("Unable to open file ") + sName);
+                if ( !outputFile->open(QIODevice::ReadWrite|QIODevice::Unbuffered)) {
+                    seterror(i18n("Unable to open file ") + sName);
                     mutex.unlock();
                     return;
                 }
             }
+
         }
         cellOut->addNewVobus((char*)(temp+itemp),DVD_VIDEO_LB_LEN,cellOut->cellList->getPosition() ,currVOB,outputFile->pos());
         outputFile->write((char*)(temp+itemp),DVD_VIDEO_LB_LEN);
 
-        backupDlg->setProgressTotal(1);
+        setProgressTotal(1);
         cellOut->cellList->setPosition( cellOut->cellList->getPosition()+1);
         if (!m_copyMenu)
             currTS->lastSector++;
@@ -445,15 +459,15 @@ uint32_t k9DVDBackup::copyMenu2(int _vts) {
     targetName=output+"/"+targetName;
 
     outputFile=new QFile(targetName);
-    if (! outputFile->open(QIODevice::WriteOnly)) {
-        seterror(tr2i18n("Unable to open file ") + targetName);
+    if (! outputFile->open(QIODevice::ReadWrite |QIODevice::Unbuffered)) {
+        seterror(i18n("Unable to open file ") + targetName);
         return 0;
     }
 
     k9DVDFile *dvdfile;
     if ((dvdfile = m_dvdread->openMenu( _vts))== 0) {
         QString stmp;
-        stmp=i18n("Unable to open menu for titleset %1",_vts);
+        stmp=i18n("Unable to open menu for titleset %1").arg(_vts);
         seterror (stmp);
         return 0;
     }
@@ -479,11 +493,12 @@ uint32_t k9DVDBackup::copyMenu2(int _vts) {
     uint32_t sector, dsi_next_vobu = 0;
     uint32_t imax=length/sizeof(cell_adr_t);
     QString c;
-    c=i18n("Extracting menu for titleset %1",_vts);
-    backupDlg->setProgressLabel(c);
-
-    backupDlg->show();
-    backupDlg->setTotalSteps(ptr[imax-1].last_sector);
+    c=i18n("Extracting menu for titleset %1").arg(_vts);
+    setProgressLabel(c);
+    if (!k9Tools::getBatchCopy()) {
+        backupDlg->show();
+    }
+    setTotalSteps(ptr[imax-1].last_sector);
 
     k9CadtList cadr;
     uint32_t nbCells=0;
@@ -519,10 +534,10 @@ uint32_t k9DVDBackup::copyMenu2(int _vts) {
         dsi_next_vobu=0;
         cell_adr_t * cellAdr=cadr.at(i);
         for (sector = cellAdr->start_sector;
-                sector <= cellAdr->last_sector; sector += dsi_next_vobu & 0x7fffffff) {
-            backupDlg->setProgress(sector);
-            if (backupDlg->getAbort()) {
-                seterror(tr2i18n("DVD backup cancelled"));
+                sector <= cellAdr->last_sector; sector += dsi_next_vobu & 0x7fffffff) {            
+            setProgress(sector);
+            if (isAborted()) {
+                seterror(i18n("DVD backup cancelled"));
             }
 
             if (error) {
@@ -572,19 +587,20 @@ void k9DVDBackup::playCell (int vts_num, k9Cell *_cell,bool _empty) {
         vts_handle=currTS->ifoTitle->getIFO();
         if (!vts_handle) {
             QString stmp;
-            stmp=i18n("Unable to open ifo file for titleset %1",vts_num);
+            stmp=i18n("Unable to open ifo file for titleset %1").arg(vts_num);
             seterror (stmp);
             //JMP            vamps->setNoData();
             return;
         }
 
-        backupDlg->setTotalSteps( vts_handle->vtsi_mat->vts_last_sector-vts_handle->vtsi_mat->vtstt_vobs  -1);
+        setTotalSteps( vts_handle->vtsi_mat->vts_last_sector-vts_handle->vtsi_mat->vtstt_vobs  -1);
         QString c;
-        c=i18n("Extracting titleset %1",vts_num);
-        backupDlg->setProgressLabel(c);
-        backupDlg->show();
+        c=i18n("Extracting titleset %1").arg(vts_num);
+        setProgressLabel(c);
+        if (!k9Tools::getBatchCopy())
+            backupDlg->show();
     } else {
-        seterror(tr2i18n("Unable to open DVD"));
+        seterror(i18n("Unable to open DVD"));
         //JMP        vamps->setNoData();
         return;
     }
@@ -594,7 +610,7 @@ void k9DVDBackup::playCell (int vts_num, k9Cell *_cell,bool _empty) {
     dvdfile = m_dvdread->openTitle (vts_num);
     if (! dvdfile) {
         QString stmp;
-        stmp=i18n("Unable to open vobs for titleset %1",vts_num);
+        stmp=i18n("Unable to open vobs for titleset %1").arg(vts_num);
         seterror( stmp);
         //JMP        vamps->setNoData();
         return;
@@ -606,9 +622,9 @@ void k9DVDBackup::playCell (int vts_num, k9Cell *_cell,bool _empty) {
     for (sector = _cell->startSector;
             sector <= _cell->lastSector; sector += dsi_next_vobu & 0x7fffffff) {
 
-        backupDlg->setProgress(sector);
-        if (backupDlg->getAbort()) {
-            seterror(tr2i18n("DVD backup cancelled"));
+        setProgress(sector);
+        if (isAborted()) {
+            seterror(i18n("DVD backup cancelled"));
         }
 
         if (error) {
@@ -807,7 +823,7 @@ uint32_t k9DVDBackup::copyVobu(k9DVDFile  *_fileHandle,uint32_t _startSector,k9V
     else
         m_cellCopyList->addFrcinbytes( nsectors*DVD_VIDEO_LB_LEN);
 
-    qApp->processEvents();
+    k9Tools::processEvents();
 
     return (end+1);
 }
@@ -1147,7 +1163,9 @@ void k9DVDBackup::updateIfo() {
     pgcit_t * pgcit = hifo->vts_pgcit;
 
     //update total VTS size with IFO size
-    currTS->lastSector += 2 *(hifo->vtsi_mat->vtsi_last_sector ) +1;
+    ifo.saveIFO();
+   // currTS->lastSector += 2 *(hifo->vtsi_mat->vtsi_last_sector ) +1;
+    currTS->lastSector += 2 *ifo.getSize() -1;
 
     hifo->vtsi_mat->vts_last_sector =   currTS->lastSector ;
 
@@ -1405,7 +1423,7 @@ void k9DVDBackup::updateVob(k9CellList *cellLst) {
     for (int iCell=0;iCell< cellLst->count();iCell++) {
         k9Cell *cell=cellLst->at(iCell);
         for (int ivobu=0; ivobu<cell->vobus.count();ivobu++) {
-            qApp->processEvents();
+            k9Tools::processEvents();
             k9Vobu * vobu = cell->vobus.at(ivobu);
             int VobNum=vobu->vobNum;
             if (error)
@@ -1421,33 +1439,29 @@ void k9DVDBackup::updateVob(k9CellList *cellLst) {
                     sName="VIDEO_TS.VOB";
                 else
                     sName.sprintf("VTS_%02d_%d.VOB",(int)currVTS,(int)VobNum);
-                dbg=i18n("Updating vob %1",sName);
+                dbg=i18n("Updating vob %1").arg(sName);
                 sName=output+"/"+sName;
                 QFileInfo finfo(sName);
                 long fileSize=finfo.size();
 
-                backupDlg->setTotalSteps(fileSize);
-                backupDlg->setProgressLabel(dbg);
+                setTotalSteps(fileSize);
+                setProgressLabel(dbg);
                 file =new QFile(sName);
-                file->open(QIODevice::ReadWrite);
+                file->open(QIODevice::ReadWrite | QIODevice::Unbuffered);
                 //file=fopen(sName,"r+b");
                 pVobNum=VobNum;
             }
             if ( file !=NULL) {
                 uint32_t sector=0;
                 long pos=vobu->vobPos;
-                backupDlg->setProgress(pos);
-                if (backupDlg->getAbort()) {
-                    seterror(tr2i18n("DVD backup canceled"));
+                setProgress(pos);
+                if (isAborted()) {
+                    seterror(i18n("DVD backup canceled"));
                     break;
                 }
 
                 bool emptyPgc=false;
-                /*		long currpos=ftell(file);
-                		long offset=pos-currpos;
-                		fseek(file,offset,SEEK_CUR);
-                */
-                //fseek(file,pos,SEEK_SET);
+
                 file->seek(pos);
                 //fread(buffer,DVD_VIDEO_LB_LEN,1,file);
                 file->read((char*)buffer,DVD_VIDEO_LB_LEN);
@@ -1543,11 +1557,10 @@ void k9DVDBackup::updateVob(k9CellList *cellLst) {
                                     sName.sprintf("/VTS_%02d_%d.VOB",(int)currVTS,(int)vobu2->vobNum);
                                     sName=output+sName;
                                     file2=new QFile(sName);
-                                    file2->open(QIODevice::ReadWrite);
+                                    file2->open(QIODevice::ReadWrite |QIODevice::Unbuffered);
                                     //file2=fopen(sName,"rb");
                                 } else
                                     file2=file;
-                                //fseek(file2,vobu2->vobPos,SEEK_SET);
                                 file2->seek(vobu2->vobPos);
                                 uchar *tmpbuff=new uchar[2048];
                                 //fread(tmpbuff,DVD_VIDEO_LB_LEN,1,file2);
@@ -1619,9 +1632,7 @@ void k9DVDBackup::updateVob(k9CellList *cellLst) {
                     pciPack.pci_gi.nv_pck_lbn =dsiPack.dsi_gi.nv_pck_lbn;
                     k9Ifo2::navRead_PCI((pci_t*)(buffer+0x2d),(uchar*)&pciPack);
                     //mise ï¿½jour du fichier
-                    //fseek(file,pos,SEEK_SET);
                     file->seek(pos);
-                    //fwrite(buffer,DVD_VIDEO_LB_LEN,1,file);
                     file->write((const char*)buffer,DVD_VIDEO_LB_LEN);
                 }
 
@@ -1697,7 +1708,7 @@ void k9DVDBackup::calcFactor() {
     double factor=m_cellCopyList->getfactor(m_withMenu,false);
     QString sFactor;
     sFactor.sprintf("%.2f",factor);
-    backupDlg->setFactor(sFactor);
+    showFactor(sFactor);
     argFactor =  factor;
     m_forcedFactor=false;
 }
@@ -1709,7 +1720,7 @@ void k9DVDBackup::forceFactor(double _factor) {
         factor=minFactor;
     QString sFactor;
     sFactor.sprintf("%.2f",factor);
-    backupDlg->setFactor(sFactor);
+    showFactor(sFactor);
     argFactor =  factor;
     m_forcedFactor=true;
     qDebug("force factor : %f   min:%f",factor,minFactor);
@@ -1722,11 +1733,11 @@ void k9DVDBackup::execute() {
 
     output=QDir::cleanPath(output +"/" + DVD->getDVDTitle());
 
-    QDir root("/");
-    root.mkdir(output);
+    QDir dir(output);
+    dir.mkpath(output);
     k9Tools::clearOutput(output);
 
-    QDir dir(output);
+
     dir.mkdir("VIDEO_TS");
     dir.mkdir("AUDIO_TS");
 
@@ -1734,7 +1745,7 @@ void k9DVDBackup::execute() {
 
     m_dvdread->openDevice(device);
     if (!m_dvdread->opened()) {
-        seterror(tr2i18n("Unable to open DVD"));
+        seterror(i18n("Unable to open DVD"));
         return;
     }
 
@@ -1748,7 +1759,7 @@ void k9DVDBackup::execute() {
     totalSize/=(1024*1024);
     totalSize = (totalSize >k9DVDSize::getMaxSize()) ? k9DVDSize::getMaxSize():totalSize;
 
-    backupDlg->setTotalMax((uint32_t)totalSize);
+    setTotalMax((uint32_t)totalSize);
 
     int lastCell;
     calcFactor();
@@ -1790,11 +1801,15 @@ void k9DVDBackup::execute() {
 
     if (!error) {
         updateIfo();
+        outputFile->close();
+        delete outputFile;
+        outputFile=NULL;
         updateVob(&currTS->cells);
         updateMainIfo();
     }
     output=sOutput;
-    backupDlg->hide();
+    if(backupDlg)
+        backupDlg->hide();
 
     if (error)
         k9Dialogs::error(errMsg,"DVD Backup");
@@ -1805,3 +1820,54 @@ void k9DVDBackup::execute() {
 void k9DVDBackup::setUserOps(bool theValue) {
     m_userOps = theValue;
 }
+
+void k9DVDBackup::setTotalSteps(uint32_t _value) {
+    if (k9Tools::getBatchCopy()) {
+        k9log::writer(QString("total :%1").arg(_value));
+        m_total=_value;
+    } else
+        backupDlg->setTotalSteps(_value);
+
+}
+
+void k9DVDBackup::setProgress (uint32_t _value) {
+    if (k9Tools::getBatchCopy())
+        k9log::writer(QString("current :%1").arg((double)_value/(double)m_total));
+    else
+        backupDlg->setProgress(_value);
+
+}
+
+void k9DVDBackup::setProgressTotal (uint32_t _value) {
+    if (k9Tools::getBatchCopy())
+        k9log::writeln(QString("total :%1").arg((double)_value/(double)m_totalMax));
+    else
+        backupDlg->setProgressTotal(_value);
+
+}
+
+void k9DVDBackup::showFactor (QString _value) {
+    if (k9Tools::getBatchCopy())
+        k9log::writeln(QString("shrink factor :%1").arg(_value));
+    else
+        backupDlg->setFactor(_value);
+
+}
+
+void k9DVDBackup::setTotalMax (uint32_t _value) {
+    if (k9Tools::getBatchCopy()) {
+        k9log::writeln(QString("total size :%1").arg(_value));
+        m_totalMax=_value;
+    } else
+        backupDlg->setTotalMax(_value);
+
+}
+
+
+void k9DVDBackup::setProgressLabel (QString _value) {
+    if (k9Tools::getBatchCopy())
+        k9log::writeln(_value);
+    else
+        backupDlg->setProgressLabel(_value);
+
+}
