@@ -138,6 +138,14 @@ private:
     void forceFactor(double _factor);
     bool error;
     void seterror(const QString &_msg);
+    bool isAborted();
+    void setTotalSteps(uint32_t);
+    void setTotalMax(uint32_t);
+    void setProgress(uint32_t);
+    void setProgressTotal(uint32_t);
+    void setProgressLabel(QString);
+    void showFactor(QString);
+    uint32_t m_total,m_totalMax;
     k9vamps *vamps;
     QQueue <k9Vobu*> vobuQueue;
     QMutex mutex;
