@@ -224,7 +224,7 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
             if (!m_mpeg2)
                 k9log::add(i18n("starting pass %1 of %2").arg(pass==0 ? 1:pass).arg(maxPass==0 ? 1 : maxPass),k9logLevel::INFO);
             m_totalBytes=0;
-            m_vamps=NULL;
+            m_vamps=new k9vamps(this,m_usecache);;
             m_player=new k9play(this);
 
             uint32_t nbSectors= m_totalSize / m_parts   ;
