@@ -14,6 +14,7 @@
 #ifndef __STDC_LIMIT_MACROS
 #endif
 #ifndef __STDC_CONSTANT_MACROS
+#define __STDC_CONSTANT_MACROS
 #endif
 
 #if defined(HAVE_INTTYPES_H)
@@ -32,16 +33,28 @@
 #include "nav_read.h"
 #include "nav_types.h"
 
-#include <qobject.h>
+#include <QObject>
 
 #ifndef DVD_BLOCK_LEN
 #define DVD_BLOCK_LEN 2048
 #endif
 
 #include "k9dvdsize.h"
-#ifndef NDEBUG
-	#define NDEBUG
-#endif
+
 #include <QtDebug>
 #include "k9dialogs.h"
+
+#include "k9log.h"
+#include "k9tools.h"
+#ifndef BACKLITE
+#include <KLocale>
 #include "k9config.h"
+#include "k9process.h"
+
+#else
+#include <QCoreApplication>
+#include "k9process2.h"
+#include "k9config2.h"
+#include "i18n.h"
+
+#endif
