@@ -72,6 +72,11 @@ QString k9Dialogs::getExistingDirectory (const QString &_initialDir) {
 }
 
 void k9Dialogs::error(const QString &_message,const QString &_title,const QStringList &_detail) {
+    if (k9Tools::getBatchCopy()) {
+        k9log::writeln(QString("Error : %1\n%2").arg(_message).arg(_detail.join("\n")));
+        return;
+    }
+
     QWidget *activeWindow=QApplication::activeWindow();
     if (activeWindow==0)
 	activeWindow=k9MainWidget;
@@ -88,6 +93,11 @@ void k9Dialogs::error(const QString &_message,const QString &_title,const QStrin
 }
 
 void k9Dialogs::information(const QString &_message, const QString &_title) {
+    if (k9Tools::getBatchCopy()) {
+        k9log::writeln(QString("Information : %1").arg(_message));
+        return;
+    }
+
     QWidget *activeWindow=QApplication::activeWindow();
     if (activeWindow==0)
 	activeWindow=k9MainWidget;
