@@ -25,6 +25,7 @@
 k9Ifo2::k9Ifo2(k9DVDRead *_dvdread) {
     _ifo=NULL;
     m_dvd=_dvdread;
+    m_VTSVobs=0;
 }
 
 
@@ -49,6 +50,13 @@ void k9Ifo2::setOutput(QString &_output) {
     output=_output;
 }
 
+void k9Ifo2::setVTSVobs(uint32_t _sector) {
+    m_VTSVobs=_sector;
+}
+
+uint32_t k9Ifo2::getSize() {
+    return m_size;
+}
 
 /*!
     \fn k9Ifo2::openIFO(int _num)
@@ -56,6 +64,10 @@ void k9Ifo2::setOutput(QString &_output) {
 ifo_handle_t * k9Ifo2::openIFO(int _num) {
     _ifo = ifoOpen(m_dvd->getDvd(), _num);
     numIfo=_num;
+    if( _ifo->vtsi_mat)
+        m_size=_ifo->vtsi_mat->vtsi_last_sector +1;
+    else
+        m_size=_ifo->vmgi_mat->vmgi_last_sector+1;
     return _ifo;
 
 }
@@ -174,6 +186,7 @@ void k9Ifo2::saveIFO() {
         }
 
         QFile ifofile (filename);
+        ifofile.remove();
         ifofile.open(QIODevice::WriteOnly);
         if (ifofile.write((char*)m_buffer,m_position) == -1) {
             QString sError("erreur");
@@ -181,6 +194,7 @@ void k9Ifo2::saveIFO() {
         ifofile.close();
 
         QFile ifofile2 (filename2);
+        ifofile2.remove();
         ifofile2.open(QIODevice::WriteOnly);
         if (ifofile2.write((char*)m_buffer,m_position) == -1) {
             QString sError("erreur");
@@ -725,9 +739,12 @@ void k9Ifo2::updateVTS(uchar *) {
 	lastSector=(round(m_position)-DVD_BLOCK_LEN) /DVD_BLOCK_LEN;
 	//lastByte=vtsi_mat->vtsi_last_sector*DVD_BLOCK_LEN +DVD_BLOCK_LEN-1;
 	vtsi_mat->vts_last_sector+=2*(lastSector-vtsi_mat->vtsi_last_sector);
-	vtsi_mat->vtstt_vobs+=lastSector-vtsi_mat->vtsi_last_sector;
+        if (m_VTSVobs !=0)
+           vtsi_mat->vtstt_vobs+=m_VTSVobs;
+        else
+           vtsi_mat->vtstt_vobs+=lastSector-vtsi_mat->vtsi_last_sector;
     }      
-    
+    m_size=lastSector+1;
     vtsi_mat->vtsi_last_sector=lastSector;
     //vtsi_mat->vtsi_last_byte=lastByte;
     if (vtsi_mat->vtsm_vobs !=0)
@@ -946,3 +963,4 @@ void k9Ifo2::navRead_PCI(pci_t *pci, uchar *buffer) {
   }
 
 }
+
