@@ -9,15 +9,15 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
+
 #include "k9process.h"
-#include <qobject.h>
+#include "k9common.h"
+#include <QObject>
 #include <QEventLoop>
-#include <qeventloop.h>
 #include "k9tools.h"
-#include <KMessageBox>
-#include <KLocale>
 #include <QDebug>
 #include "k9dialogs.h"
+
 k9Process::k9Process(QObject *parent, const char *)
  : KProcess(parent),m_waitSync(false)
 {
@@ -59,12 +59,14 @@ void k9Process::sync() {
 void k9Process::slotReadyReadStandardError() {
    QByteArray ba=readAllStandardError();
    getStderr(ba);
-   emit receivedStderr(this, ba.data(), ba.length());
+   emit receivedStderr(ba.data(), ba.length());
+    emit receivedStderr(this,ba.data(), ba.length());
 }
 
 void k9Process::slotReadyReadStandardOutput() {
    QByteArray ba=readAllStandardOutput();
    getStdout(ba);
+   emit receivedStdout( ba.data(), ba.length());
    emit receivedStdout(this, ba.data(), ba.length());
 }
 
