@@ -35,6 +35,9 @@ public:
    static const QString getTempPath() ;
    static const QString randomFileName();
    static QString findExe(const QString _program);
+   static void processEvents();
+   static void setBatchCopy(bool);
+   static bool getBatchCopy();
 };
 
 #ifdef BACKLITE
