@@ -13,9 +13,10 @@
 #include <avcodec.h>
 #include <qimage.h>
 #include <dlfcn.h>
-#include <klocale.h>
+#include "k9common.h"
 
 #ifdef HAVE_SWSCALE
+
 #include "swscale.h"
 
 static int sws_flags = SWS_BICUBIC;
@@ -48,21 +49,16 @@ k9AviDecode::k9AviDecode(QObject *parent, const char *)
     m_error="";
     QStringList errs;
     if (!CodecHandle) {
-        errs << i18n("Cannot open then library %1","libavcodec");
+        errs << i18n("Cannot open then library %1").arg("libavcodec");
     }
     if (!FormatHandle ) {
-        errs << i18n("Cannot open then library %1","libavformat");
+        errs << i18n("Cannot open then library %1").arg("libavformat");
     }
 #ifdef HAVE_SWSCALE
     if (!SwscaleHandle) {
-        errs << i18n("Cannot open then library %1","libswscale");
+        errs << i18n("Cannot open then library %1").arg("libswscale");
     }
 #endif
-    if (errs.count() >0) {
-        m_error=errs.join("\n");
-        k9Dialogs::error(m_error,"k9copy",QStringList());
-        return;
-    }
 
     av_register_all = (av_register_all_t)dlsym(FormatHandle,"av_register_all");
     av_open_input_file = (av_open_input_file_t)dlsym(FormatHandle,"av_open_input_file");
@@ -75,7 +71,12 @@ k9AviDecode::k9AviDecode(QObject *parent, const char *)
     avpicture_fill = (avpicture_fill_t)dlsym(CodecHandle,"avpicture_fill");
     av_read_frame = (av_read_frame_t)dlsym(FormatHandle,"av_read_frame");
     avcodec_decode_video = (avcodec_decode_video_t)dlsym(CodecHandle,"avcodec_decode_video");
+#ifndef HAVE_SWSCALE
     img_convert = (img_convert_t)dlsym(CodecHandle,"img_convert");
+//if img_convert is null (deprecated in ffmpeg), we need libswscale
+    if (!img_convert)
+      errs << i18n("Cannot open then library %1").arg("libswscale");
+#endif
     av_free = (av_free_t)dlsym(CodecHandle,"av_free");
     av_free_packet = (av_free_packet_t)dlsym(CodecHandle,"av_free_packet");
     if (av_free_packet==0)
@@ -90,9 +91,14 @@ k9AviDecode::k9AviDecode(QObject *parent, const char *)
     sws_getContext=(sws_getContext_t)dlsym(SwscaleHandle,"sws_getContext");
     sws_scale= (sws_scale_t)dlsym(SwscaleHandle,"sws_scale");
 #endif
-
-
     av_gettime=(av_gettime_t)dlsym(FormatHandle,"av_gettime");
+    
+    if (errs.count() >0) {
+        m_error=errs.join("\n");
+        k9Dialogs::error(m_error,"k9copy",QStringList());
+        return;
+    }
+    
     av_register_all();
     m_opened=false;
 
@@ -126,7 +132,7 @@ bool k9AviDecode::open(const QString & _fileName) {
 
     // Open video file
     if (av_open_input_file(&m_FormatCtx, _fileName.toUtf8(), NULL, 0, NULL)!=0) {
-        m_error=i18n("Couldn't open the file %1",_fileName);
+        m_error=i18n("Couldn't open the file %1").arg(_fileName);
         return false; // Couldn't open file}
     }
 // Retrieve stream information
