@@ -17,6 +17,10 @@
 #ifdef BACKLITE
 #include "aboutbox.h"
 #include <QActionGroup>
+#include <QStatusBar>
+#include <QStyleFactory>
+#include <QMenuBar>
+#include <QToolBar>
 #else
 #include <kdeversion.h>
 #include <kstatusbar.h>
@@ -27,6 +31,7 @@
 #include <KShortcutsDialog>
 #include <KActionCollection>
 #include "k9importfiles.h"
+#include <QStyleFactory>
 #endif
 #include <kaction.h>
 #include "kviewmpeg2.h"
@@ -49,6 +54,8 @@ k9Copy::k9Copy()
     m_import=NULL;
     m_mp4=NULL;
     setAcceptDrops(true);
+    m_style=qApp->style()->objectName();
+
     setDockOptions(QMainWindow::AllowTabbedDocks |QMainWindow::AnimatedDocks);
     setCorner(Qt::BottomRightCorner,Qt::RightDockWidgetArea);
     setCorner(Qt::TopRightCorner,Qt::RightDockWidgetArea);
@@ -62,9 +69,8 @@ k9Copy::k9Copy()
     statusBar()->show();
     m_drives=new k9CdDrives(this);
     k9Config config;
-
 #ifdef BACKLITE
-    m_style=qApp->style()->objectName();
+
     if (config.getPrefStyle()!="")
         qApp->setStyle(config.getPrefStyle());
     createCopyWindows();
@@ -100,6 +106,28 @@ k9Copy::k9Copy()
 }
 
 
+bool k9Copy::foundGtkStyle() {
+    foreach (QString s , QStyleFactory::keys()) {
+        if (s.toLower()=="gtk+") {
+             return true;
+        }
+    }
+    return false;
+}
+
+void k9Copy::setGtkStyle(bool _checked) {
+#ifndef BACKLITE
+    if (_checked) {
+        if (foundGtkStyle())
+         qApp->setStyle("gtk+");
+    } else
+         qApp->setStyle(m_style);
+    k9Config config;
+    config.setGtkStyle(_checked);
+    config.save();
+#endif
+}
+
 void k9Copy::createCopyWindows() {
     m_dockMP4=new QDockWidget(this);
     m_dockFactor=new QDockWidget(this);
@@ -279,7 +307,6 @@ void k9Copy::setupActions() {
     connect(m_actions["preferences"],SIGNAL(triggered(bool)),SLOT(preferences()));
     configureMenu->addAction(m_actions["preferences"]);
 
-
     k9Config config;
 
     QActionGroup *grp=new QActionGroup(this);
@@ -324,9 +351,7 @@ void k9Copy::setupActions() {
     toolbar->addAction(ejectAction);
     toolbar->addAction(m_actions["quit"]);
 
-#else
-
-
+#else 
     m_actions["open"]=KStandardAction::open(this, SLOT(fileOpen()), (QObject*)actionCollection());
     m_actions["quit"]=KStandardAction::quit(this, SLOT(quit()),(QObject*) actionCollection());
     m_actions["preferences"]=KStandardAction::preferences(this,SLOT(preferences()),(QObject*)actionCollection());
@@ -336,11 +361,29 @@ void k9Copy::setupActions() {
     setStandardToolBarMenuEnabled(TRUE);
     createStandardStatusBarAction();
 
+    QStringList slEnv=QProcess::systemEnvironment();
+    bool bGtk=true;
+    foreach (QString env,slEnv) {
+        if (env.startsWith("KDE_FULL_SESSION=true"))
+            bGtk=false;
+    }
+    if (bGtk && foundGtkStyle()) {
+        m_actions["gtk-style"]=new KAction(KIcon("configure"),i18n("Use Gtk Style"),this);
+        m_actions["gtk-style"]->setCheckable(true);
+        connect(m_actions["gtk-style"],SIGNAL(triggered(bool)),this,SLOT(setGtkStyle(bool)));
+        k9Config config;
+        if (config.getGtkStyle()) {
+            m_actions["gtk-style"]->setChecked(true);
+            qApp->setStyle("gtk+");
+        }
+
+    }
+
     actionCollection()->addAction("Copy",CopyAction);
     actionCollection()->addAction("Eject",ejectAction);
     actionCollection()->addAction("Wizard",wizardAction);
     actionCollection()->addAction("author",authorAction);
-
+    actionCollection()->addAction("gtk-style",m_actions["gtk-style"]);
 #endif
 
 }
