@@ -14,7 +14,6 @@
 
 #include "k9common.h"
 #include "ui_ffmpegCmdGen.h"
-#include "k9process.h"
 
 class k9ffmpegCmdGen : public QWidget {
     Q_OBJECT
@@ -40,7 +39,7 @@ private:
     QString m_codecs;
     void readCodecs();
 protected slots:
-   void getStdout(KProcess*, char*,int);
+   void getStdout(char*,int);
 };
 
 
