@@ -19,21 +19,20 @@
 ***************************************************************************/
 
 #include "kconfigdlg.h"
+#ifndef BACKLITE
 #include "kmessagebox.h"
-
 #include <kiconloader.h>
-#include <kpushbutton.h>
-
 #include <kstdguiitem.h>
 #include <kguiitem.h>
-#include "k9config.h"
-
+#endif
+#include <kpushbutton.h>
+#include <kdialog.h>
 kConfigDlg::kConfigDlg(QWidget *parent)
     : QWidget(parent)
 {
   Ui_configDlg.setupUi(this);
-  setWindowTitle(KDialog::makeStandardCaption(i18n("Devices"),this));
 
+  setWindowTitle(KDialog::makeStandardCaption(i18n("Devices"),this));
   QStringList ldev;
   QStringList llabels;
   QStringList lIO;
@@ -85,9 +84,10 @@ kConfigDlg::kConfigDlg(QWidget *parent)
 //    buttonOk->setIcon(KStandardGuiItem::ok().icon());
      connect(Ui_configDlg.bAdd,SIGNAL(clicked()),this,SLOT(bAddClick()));
      connect(Ui_configDlg.bRemove,SIGNAL(clicked()),this,SLOT(bRemoveClick()));
+#ifndef BACKLITE
      Ui_configDlg.bAdd->setGuiItem(KStandardGuiItem::Add);
      Ui_configDlg.bRemove->setGuiItem(KStandardGuiItem::Remove);
-
+#endif
 
 }
 
