@@ -19,10 +19,19 @@
  ***************************************************************************/
 #ifndef K9PHONON_H
 #define K9PHONON_H
-
+#include "k9common.h"
 #include <QWidget>
 #include "ui_phonon.h"
 #include "k9dvd.h"
+#ifdef BACKLITE
+#include <phonon/mediaobject.h>
+#include <phonon/mediacontroller.h>
+#include <phonon/path.h>
+#include <phonon/audiooutput.h>
+#include <phonon/mediaobject.h>
+#include <phonon/videowidget.h>
+#include <phonon/mediasource.h>
+#else
 #include <Phonon/MediaObject>
 #include <Phonon/MediaController>
 #include <Phonon/Path>
@@ -30,6 +39,7 @@
 #include <Phonon/Global>
 #include <Phonon/VideoWidget>
 #include <Phonon/MediaSource>
+#endif
 #include <QLayout>
 /**
 	@author Jean-Michel <jm_petit@laposte.net>
