@@ -226,9 +226,8 @@ void k9xinePlayer::init(WId _wid) {
     m_height       = 200;
 
     XLockDisplay(display);
-    //m_wid = XCreateSimpleWindow(display, XDefaultRootWindow(display),m_xpos, m_ypos, m_width, m_height, 1, 0, 0);
     m_wid = XCreateSimpleWindow(display, _wid,m_xpos, m_ypos, m_width, m_height, 1, 0, 0);
-    //m_wid=_wid;
+    XSelectInput (display, _wid, INPUT_MOTION);
     XSelectInput (display, m_wid, INPUT_MOTION);
 
     XMapRaised(display, m_wid);
@@ -252,7 +251,7 @@ void k9xinePlayer::init(WId _wid) {
     if ((vo_port = xine_open_video_driver(xine,
                                           m_vo.toAscii(), XINE_VISUAL_TYPE_X11, (void *) &vis)) == NULL) {
       //  printf("I'm unable to initialize '%s' video driver. Giving up.\n", m_vo.toAscii());
-        return ;
+      //  return ;
     }
 
     ao_port     = xine_open_audio_driver(xine , m_ao.toAscii(), NULL);
@@ -260,8 +259,8 @@ void k9xinePlayer::init(WId _wid) {
     event_queue = xine_event_new_queue(stream);
     xine_event_create_listener_thread(event_queue, event_listener, this);
 
-    xine_gui_send_vo_data(stream, XINE_GUI_SEND_DRAWABLE_CHANGED, (void *) m_wid);
-    xine_gui_send_vo_data(stream, XINE_GUI_SEND_VIDEOWIN_VISIBLE, (void *) 1);
+    xine_port_send_gui_data(vo_port, XINE_GUI_SEND_DRAWABLE_CHANGED, (void *) m_wid);
+    xine_port_send_gui_data(vo_port, XINE_GUI_SEND_VIDEOWIN_VISIBLE, (void *) 1);
     m_execute=true;
 
 }
@@ -284,7 +283,8 @@ void k9xinePlayer::quit() {
 void k9xinePlayer::update() {
     if (stream && !running ) {
         if (m_mutex.tryLock()) {
-           xine_gui_send_vo_data(stream, XINE_GUI_SEND_DRAWABLE_CHANGED, (void *) m_wid);
+            QApplication::syncX();
+           xine_port_send_gui_data(vo_port , XINE_GUI_SEND_DRAWABLE_CHANGED, (void *) m_wid);
            m_mutex.unlock();
         }
     }
@@ -293,6 +293,7 @@ void k9xinePlayer::update() {
 void k9xinePlayer::execute() {
     m_thread->setDisplay(display);
     m_thread->start();
+  //  kapp->exec();
 }
 void k9xineThread::run() {
     m_execute=true; 
@@ -317,7 +318,7 @@ void k9xineThread::run() {
         case Expose:
             if (xevent.xexpose.count != 0)
                 break;
-            xine_gui_send_vo_data(m_player->getStream(), XINE_GUI_SEND_EXPOSE_EVENT, &xevent);
+            xine_port_send_gui_data(m_player->getvoport(), XINE_GUI_SEND_EXPOSE_EVENT, &xevent);
             break;
         }
     }
@@ -350,7 +351,7 @@ void k9xinePlayer::end() {
     XCloseDisplay (display);
     m_mutex.unlock();
     delete m_thread;
-    qApp->exit();
+    kapp->exit();
 }
 
 
